@@ -19,7 +19,7 @@ T = typing.TypeVar("T")
 
 class UnitOfWork(abc.ABC):
     def __init__(self):
-        self._resources: typing.Optional[
+        self.__resources: typing.Optional[
             typing.Set[resources.Resource[typing.Any]]
         ] = None
         self.__shared_resources: typing.Optional[SharedResources] = None
@@ -29,7 +29,7 @@ class UnitOfWork(abc.ABC):
         self.__shared_resources = SharedResources(*self.create_shared_resources())
         fresh_resources = self.create_resources(self.__shared_resources)
         _check_for_duplicate_resource_names(fresh_resources)
-        self._resources = set(fresh_resources)
+        self.__resources = set(fresh_resources)
         self.__resources_validated = True
         return self
 
@@ -39,7 +39,7 @@ class UnitOfWork(abc.ABC):
             self.rollback()
         except exceptions.RollbackErrors as e:
             errors += e.rollback_errors
-        self._resources = None
+        self.__resources = None
         assert self.__shared_resources is not None
         self.__shared_resources.close()
         self.__shared_resources = None
@@ -47,7 +47,7 @@ class UnitOfWork(abc.ABC):
             raise exceptions.RollbackErrors(*errors)
 
     def get_resource(self, resource_type: typing.Type[R], /) -> R:
-        if self._resources is None:
+        if self.__resources is None:
             raise exceptions.OutsideTransactionError()
         else:
             return typing.cast(
@@ -57,19 +57,19 @@ class UnitOfWork(abc.ABC):
     def get_resource_by_name(
         self, resource_name: str, /
     ) -> resources.Resource[typing.Any]:
-        if self._resources is None:
+        if self.__resources is None:
             raise exceptions.OutsideTransactionError()
         else:
             try:
                 return next(
                     resource
-                    for resource in self._resources
+                    for resource in self.__resources
                     if resource.resource_name() == resource_name
                 )
             except StopIteration:
                 raise exceptions.MissingResourceError(
                     resource_name=resource_name,
-                    available_resources={r.resource_name() for r in self._resources},
+                    available_resources={r.resource_name() for r in self.__resources},
                 )
 
     @abc.abstractmethod
@@ -86,10 +86,10 @@ class UnitOfWork(abc.ABC):
 
     def rollback(self):
         errors: typing.List[exceptions.RollbackError] = []
-        if self._resources is None:
+        if self.__resources is None:
             raise exceptions.OutsideTransactionError()
         else:
-            for resource in self._resources:
+            for resource in self.__resources:
                 try:
                     resource.rollback()
                 except Exception as e:
@@ -106,10 +106,10 @@ class UnitOfWork(abc.ABC):
     def save(self):
         # noinspection PyBroadException
         try:
-            if self._resources is None:
+            if self.__resources is None:
                 raise exceptions.OutsideTransactionError()
             else:
-                for resource in self._resources:
+                for resource in self.__resources:
                     resource.save()
         except:
             self.rollback()
